"""Tests that CRUD maven remotes."""
import json
import uuid

import pytest

from pulpcore.client.pulp_maven.exceptions import ApiException


@pytest.mark.parallel
def test_remote_crud_workflow(maven_remote_api_client, gen_object_with_cleanup, monitor_task):
    remote_data = {"name": str(uuid.uuid4()), "url": "http://example.com"}
    remote = gen_object_with_cleanup(maven_remote_api_client, remote_data)
    assert remote.url == remote_data["url"]
    assert remote.name == remote_data["name"]

    with pytest.raises(ApiException) as exc:
        gen_object_with_cleanup(maven_remote_api_client, remote_data)
    assert exc.value.status == 400
    assert json.loads(exc.value.body) == {"name": ["This field must be unique."]}

    update_response = maven_remote_api_client.partial_update(
        remote.pulp_href, {"url": "https://example.com"}
    )
    task = monitor_task(update_response.task)
    assert task.created_resources == []

    remote = maven_remote_api_client.read(remote.pulp_href)
    assert remote.url == "https://example.com"

    all_new_remote_data = {"name": str(uuid.uuid4()), "url": "http://example.com"}
    update_response = maven_remote_api_client.update(remote.pulp_href, all_new_remote_data)
    task = monitor_task(update_response.task)
    assert task.created_resources == []

    remote = maven_remote_api_client.read(remote.pulp_href)
    assert remote.name == all_new_remote_data["name"]
    assert remote.url == all_new_remote_data["url"]


@pytest.mark.parallel
def test_create_maven_remote_with_invalid_parameter(
    maven_remote_api_client, gen_object_with_cleanup
):
    unexpected_field_remote_data = {
        "name": str(uuid.uuid4()),
        "url": "http://example.com",
        "foo": "bar",
    }

    with pytest.raises(ApiException) as exc:
        gen_object_with_cleanup(maven_remote_api_client, unexpected_field_remote_data)
    assert exc.value.status == 400
    assert json.loads(exc.value.body) == {"foo": ["Unexpected field"]}


@pytest.mark.parallel
def test_create_maven_remote_without_url(maven_remote_api_client, gen_object_with_cleanup):
    with pytest.raises(ApiException) as exc:
        gen_object_with_cleanup(maven_remote_api_client, {"name": str(uuid.uuid4())})
    assert exc.value.status == 400
    assert json.loads(exc.value.body) == {"url": ["This field is required."]}


@pytest.mark.parallel
def test_default_remote_policy_immediate(maven_remote_api_client, gen_object_with_cleanup):
    remote_data = {"name": str(uuid.uuid4()), "url": "http://example.com"}
    remote = gen_object_with_cleanup(maven_remote_api_client, remote_data)
    assert remote.policy == "immediate"



# Generated by Django 2.2.3 on 2019-08-04 01:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [("core", "0003_remove_upload_completed")]

    operations = [
        migrations.CreateModel(
            name="MavenDistribution",
            fields=[
                (
                    "basedistribution_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="core.BaseDistribution",
                    ),
                )
            ],
            options={"abstract": False},
            bases=("core.basedistribution",),
        ),
        migrations.CreateModel(
            name="MavenRemote",
            fields=[
                (
                    "remote_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="core.Remote",
                    ),
                )
            ],
            options={"abstract": False},
            bases=("core.remote",),
        ),
        migrations.CreateModel(
            name="MavenArtifact",
            fields=[
                (
                    "content_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="core.Content",
                    ),
                ),
                ("group_id", models.CharField(max_length=255)),
                ("artifact_id", models.CharField(max_length=255)),
                ("version", models.CharField(max_length=255)),
                ("filename", models.CharField(max_length=255)),
            ],
            options={
                "unique_together": {("group_id", "artifact_id", "version", "filename")}
            },
            bases=("core.content",),
        ),
    ]



#!/usr/bin/env python3

from setuptools import find_packages, setup

with open("requirements.txt") as requirements:
    requirements = requirements.readlines()

setup(
    name="pulp-maven",
    version="0.6.0",
    description="pulp-maven plugin for the Pulp Project",
    license="GPLv2+",
    author="Pulp Project Developers",
    author_email="pulp-dev@redhat.com",
    url="http://www.pulpproject.org/",
    python_requires=">=3.8",
    install_requires=requirements,
    include_package_data=True,
    packages=find_packages(exclude=["tests", "tests.*"]),
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
        "Operating System :: POSIX :: Linux",
        "Development Status :: 4 - Beta",
        "Framework :: Django",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    entry_points={"pulpcore.plugin": ["pulp_maven = pulp_maven:default_app_config"]},
)
